@@ -194,6 +194,8 @@ pub trait LogParser: DynClone + Send {
     fn description(&self) -> &str;
     /// Get parser schema
     fn schema(&self) -> &'static FieldSchema;
+    /// Get a log generator to test this parser
+    fn generator(&self) -> Box<dyn LogGenerator>;
 }
 clone_trait_object!(LogParser);
 
@@ -230,3 +232,12 @@ pub enum LogParsingError {
     ParserError(SiemLog),
 }
 
+
+pub trait LogGenerator {
+    /// Generate a random log
+    fn log(&self) -> String;
+    /// Of the total overall logs that are generated in an organization, 
+    /// whats the procentage of logs generated by this source?
+    /// The bigger, the most probability of being generated
+    fn weight(&self) -> u8;
+}
